import { BuildSummary, CodeEngineEventEmitter, ModuleDefinition, PluginDefinition } from "@code-engine/types";
import { Config } from "./config";
declare const codeEngineEventEmitter: new () => CodeEngineEventEmitter;
/**
 * The main CodeEngine class.
 */
export declare class CodeEngine extends codeEngineEventEmitter {
    constructor(config?: Config);
    /**
     * Returns all CodeEngine instances that have been created and not yet disposed.
     */
    static get instances(): ReadonlyArray<CodeEngine>;
    /**
     * Indicates whether the `dispose()` method has been called.
     * Once disposed, a CodeEngine instance is no longer usable.
     */
    get isDisposed(): boolean;
    /**
     * Loads one or more CodeEngine plugins.
     */
    use(...plugins: PluginDefinition[]): Promise<void>;
    /**
     * Imports one or more JavaScript modules in all worker threads.
     */
    import(...modules: Array<string | ModuleDefinition<void>>): Promise<void>;
    /**
     * Deletes the contents of the destination(s).
     */
    clean(): Promise<void>;
    /**
     * Runs a full build of all source files.
     */
    build(): Promise<BuildSummary>;
    /**
     * Watches source files for changes and runs incremental re-builds whenever changes are detected.
     *
     * @param delay
     * The time (in milliseconds) to wait after a file change is detected before starting a build.
     * This allows multiple files that are changed together to all be re-built together.
     */
    watch(delay?: number): void;
    /**
     * Releases system resources that are held by this CodeEngine instance.
     * Once `dispose()` is called, the CodeEngine instance is no longer usable.
     */
    dispose(): Promise<void>;
    /**
     * Disposes all CodeEngine instances.
     */
    static disposeAll(): Promise<void>;
    /**
     * Returns a string representation of the CodeEngine instance.
     */
    toString(): string;
    /**
     * Returns the name to use for `Object.toString()`.
     */
    get [Symbol.toStringTag](): string;
}
export {};
